@@ -1,7 +1,7 @@
 package File::Digest;
 
-our $DATE = '2019-08-21'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2019-09-12'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,10 +45,14 @@ my %arg_files = (
 
 my %arg_algorithm = (
     algorithm => {
-        schema => ['str*', in=>[qw/crc32 md5 sha1 sha224 sha256 sha384 sha512 sha512224 sha512256/]],
+        schema => ['str*', in=>[qw/crc32 md5 sha1 sha224 sha256 sha384 sha512 sha512224 sha512256 Digest/]],
         default => 'md5',
         cmdline_aliases => {a=>{}},
     },
+    digest_args => {
+        schema => ['array*', of=>'str*', 'x.perl.coerce_rules'=>['str_comma_sep']],
+        cmdline_aliases => {A=>{}},
+    },
 );
 
 $SPEC{digest_file} = {
@@ -99,6 +103,11 @@ sub digest_file {
         my $ctx = Digest::CRC->new(type=>'crc32');
         $ctx->addfile($fh);
         return [200, "OK", $ctx->hexdigest];
+    } elsif ($algo eq 'Digest') {
+        require Digest;
+        my $ctx = Digest->new(@{ $args{digest_args} // [] });
+        $ctx->addfile($fh);
+        return [200, "OK", $ctx->hexdigest];
     } else {
         return [400, "Invalid/unsupported algorithm '$algo'"];
     }
@@ -154,7 +163,7 @@ File::Digest - Calculate file checksum/digest (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.008 of File::Digest (from Perl distribution File-Digest), released on 2019-08-21.
+This document describes version 0.009 of File::Digest (from Perl distribution File-Digest), released on 2019-09-12.
 
 =head1 SYNOPSIS
 
@@ -188,6 +197,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<algorithm> => I<str> (default: "md5")
 
+=item * B<digest_args> => I<array[str]>
+
 =item * B<file>* => I<filename>
 
 Filename ("-" means stdin).
@@ -225,6 +236,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<algorithm> => I<str> (default: "md5")
 
+=item * B<digest_args> => I<array[str]>
+
 =item * B<files>* => I<array[filename]>
 
 Array of filenames (filename "-" means stdin).
